# pyquantsim Simulation package

Contains the simulation code for the application

## Project structure

```
docs/           # Documentation
pyquantsim/       # Library
 | - Circuit/   # Circuit wise representation
 | - gates/     # contains the basic gates
tests/      # Tests

```
